<?php

namespace Drupal\info_messages;

use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\PageCache\ResponsePolicy\KillSwitch;
use Symfony\Component\HttpFoundation\Session\Flash\FlashBagInterface;

class InfoMessenger extends Messenger implements InfoMessengerInterface {

  /**
   * The flash bag.
   *
   * @var \Symfony\Component\HttpFoundation\Session\Flash\FlashBagInterface
   */
  protected $flashBag;

  /**
   * The kill switch.
   *
   * @var \Drupal\Core\PageCache\ResponsePolicy\KillSwitch
   */
  protected $killSwitch;

  /**
   * Messenger constructor.
   *
   * @param \Symfony\Component\HttpFoundation\Session\Flash\FlashBagInterface $flash_bag
   *   The flash bag.
   * @param \Drupal\Core\PageCache\ResponsePolicy\KillSwitch $killSwitch
   *   The kill switch.
   */
  public function __construct(MessengerInterface $inner_service, FlashBagInterface $flash_bag, KillSwitch $killSwitch) {
    $this->flashBag = $flash_bag;
    $this->killSwitch = $killSwitch;
    $this->innerService = $inner_service;

    parent::__construct($flash_bag, $killSwitch);
  }

  public function __call($method, $args) {
    return call_user_func_array(array($this->innerService, $method), $args);
  }

  /**
   * Adds a new status message to the queue.
   *
   * @param string|\Drupal\Component\Render\MarkupInterface $message
   *   (optional) The translated message to be displayed to the user. For
   *   consistency with other messages, it should begin with a capital letter
   *   and end with a period.
   * @param bool $repeat
   *   (optional) If this is FALSE and the message is already set, then the
   *   message won't be repeated. Defaults to FALSE.
   *
   * @return $this
   */
  public function addInfo($message, $repeat = FALSE) {
    return $this->addMessage($message, static::TYPE_INFO, $repeat);
  }

}